#!/bin/bash

# Change working directory to the profile path, passed as an argument
profileDirPath=$1

cd "$profileDirPath"

backupDir=~/Desktop/Old\ Firefox\ Files
rm -Rf "$backupDir"
mkdir "$backupDir"

echo "profileDirPath received as argument:" > "$backupDir/Firefox3Rewriter.log.txt"
echo "   $profileDirPath" >> "$backupDir/Firefox3Rewriter.log.txt"
echo >> "$backupDir/Firefox3Rewriter.log.txt"
echo "present working directory:" >> "$backupDir/Firefox3Rewriter.log.txt"
echo "   $PWD" >> "$backupDir/Firefox3Rewriter.log.txt"

# Remove a potentially troublesome line from prefs.js
cat prefs.js | grep --invert-match browser.places.importBookmarksHTML > prefsNew.js
# And append a line which means the opposite
echo "user_pref(\"browser.places.importBookmarksHTML\", false);" >> prefsNew.js
echo >> "$backupDir/Firefox3Rewriter.log.txt"
if [ -d prefs.js ]; then
	mv -f prefs.js "$backupDir/prefs.js"
fi
if [ -d prefsNew.js ]; then
	mv -f prefsNew.js prefs.js
fi
echo "Text in revised prefs.js:" >> "$backupDir/Firefox3Rewriter.log.txt"
echo >> "$backupDir/Firefox3Rewriter.log.txt"
cat prefs.js >> "$backupDir/Firefox3Rewriter.log.txt"

arch=`uname -p`
if [ "$arch" == "x86_64" ]
then
	mysqlite=$thisDir/sqlite3
elif [ "$arch" == "i386" ]
then
	mysqlite=$thisDir/sqlite3
elif [ "$arch" == "ppc" ]
then
	mysqlite=$thisDir/sqlite359
fi

ffDatabase=$profileDirPath/places.sqlite
thisDir=`dirname $0`
cd $thisDir

$mysqlite "$ffDatabase" .dump > placesDump.txt
# .dump will produce a line including sqlite_sequence which is some kind of bug
# It causes an error when later reading it in.  So I grep out that line
cat placesDump.txt | grep --invert-match sqlite_sequence > placesFilteredDump.txt
if [ -d "$ffDatabase" ]; then
	mv -f "$ffDatabase" "$backupDir/places.sqlite"
fi
$mysqlite "$ffDatabase" '.read placesFilteredDump.txt'

# Clean up.  Instead of deleting, we move to the desktop archive in case we need to do any troubleshooting.
if [ -d placesFilteredDump.txt ]; then
	mv placesFilteredDump.txt "$backupDir/placesDump.txt"
fi
if [ -d prefs.js ]; then
	mv placesFilteredDump.txt "$backupDir/placesFilteredDump.txt"
fi

# This may be necessary to keep Firefox from reverting to one of the backups.  Or maybe not.  Anyhow, at least it gets all of the user's backups in one place on the desktop, and the less crap we give Firefox to play with, the fewer ways it might find to screw things up.
if [ -d "$profileDirPath/bookmarkbackups" ]; then
	mv -f "$profileDirPath/bookmarkbackups" "$backupDir/bookmarkbackups"
fi
# Ditto, regarding the old Firefox 2 bookmarks
if [ -d "$profileDirPath/bookmarks.html" ]; then
	mv -f "$profileDirPath/bookmarks.html" "$backupDir/bookmarks(OldFirefox2).html"
fi

# Again, I'm not sure if this does anything, but I have seen instances where Firefox may leave the places.sqlite-journal empty file, which I believe is a "file in use" sentinel, for some reason.  Get rid of it.
rm -f places.sqlite-journal

# Return the full path to the places.sqlite file.
echo $ffDatabase
